@@ -212,7 +212,7 @@ class RegressionRunner(BaseRunner):
                 if keys is None:
                     print('ERROR! Keys not found. ')
                     return None
-                features, stats, coefs, carrysats = self.__retrieve_train_results(
+                features, stats, coefs, carrysats, elasticities = self.__retrieve_train_results(
                     request_id=model_id,
                     client_id=client_id,
                     fref=keys['fref_exp'],
@@ -353,7 +353,7 @@ class RegressionRunner(BaseRunner):
                     step=step,
                     verbose=verbose)
                 if res2['response']['status'] in ['Complete']:
-                    features, stats, coefs, carrysats = self.__retrieve_train_results(
+                    features, stats, coefs, carrysats, elasticities = self.__retrieve_train_results(
                         request_id=request_id, client_id=client_id,
                         fref=fref_exp, verbose=verbose)
                 else:
